summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/ZeroTierOne.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/ZeroTierOne.h b/include/ZeroTierOne.h
index 1707174a..670cf56d 100644
--- a/include/ZeroTierOne.h
+++ b/include/ZeroTierOne.h
@@ -338,14 +338,14 @@ typedef void (*ZT1_StatusCallback)(enum ZT1_StatusCode,const char *,const void *
*
* @param node Result parameter: pointer to set to new node instance
* @param homePath ZeroTier home path for storing state information
* @param lanConfigUpdateCallback Function to be called when virtual LANs are created, deleted, or their config parameters change
* @param statusCallback Function to receive status updates and non-fatal error notices
* @return OK (0) or error code if a fatal error condition has occurred
*/
enum ZT1_ReturnValue ZT1_Node_new(
ZT1_Node **node,
const char *homePath,
- ZT1_VirtualLanConfigCallback *lanConfigUpdateCallback,
+ ZT1_VirtualPortConfigCallback *portConfigCallback,
ZT1_StatusCallback *statusCallback);
/**
@@ -338,14 +338,14 @@ typedef void (*ZT1_StatusCallback)(enum ZT1_StatusCode,const char *,const void *
* @param node Result parameter: pointer to set to new node instance
* @param homePath ZeroTier home path for storing state information
- * @param lanConfigUpdateCallback Function to be called when virtual LANs are created, deleted, or their config parameters change
+ * @param portConfigCallback Function to be called when virtual LANs are created, deleted, or their config parameters change
* @param statusCallback Function to receive status updates and non-fatal error notices
* @return OK (0) or error code if a fatal error condition has occurred